#' Information on activity.
#'
#' List of data.frame giving complementary information on activities.
#'
#' @format A list of data.frame:
#' \strong{category}: data.frame giving the correspondence between models and 
#' category of activities
#' \describe{
#' 	\item{model_name}{character, name of the model}
#' 	\item{category}{character, name of the category of activity}
#' 	\item{category_label_fr}{character, label in French}
#' 	\item{APE_05}{character, APE code at level 5 of the model}
#' 	\item{APE_05_label_fr}{character, label in French of the APE code}
#' 	\item{n_employee}{double, number of employee attached to the given model}
#' }
#' \strong{typology}: data.frame giving the correspondence between category of 
#' activities and APE codes at level 5
#' \describe{
#' 	\item{APE_05}{character, APE code at level 5}
#' 	\item{type}{character, type of stake, only those of type activity are used
#'      for extrapolation}
#' 	\item{category}{character, name of the category of activity attached to
#'      the APE code}
#' 	\item{category_label_fr}{character, label in French}
#' 	\item{APE_05_label_fr}{character, label in French of the APE code}
#' }
#' \strong{esane}: data.frame giving the correspondence between category of
#'  activities and APE codes at level 5, with information coming frome esane
#'  data base (INSEE)
#' \describe{
#' 	\item{APE_05}{character, APE code at level 5}
#' 	\item{type}{character, type of stake, only those of type activity are used
#'      for extrapolation}
#' 	\item{category}{character, name of the category of activity attached to
#'      the APE code}
#' 	\item{category_label_fr}{character, label in French}
#' 	\item{APE_05_label_fr}{character, label in French of the APE code}
#' 	\item{n}{double, number of enterprises for all the activities in France of
#'      the given APE code}
#' 	\item{employee}{double, number of employee for all the activities in
#'      France of the given APE code}
#' 	\item{equipment}{double, value of equipment for all the activities in
#'      France of the given APE code}
#' 	\item{stock}{double, value of stock for all the activities in France of
#'      the given APE code}
#' 	\item{level}{factor, level at which data could be extracted from esane
#'      data base (N1, N2, N3 or N5) or "no data" when nothing was available}
#' 	\item{ACTENTNOMESS}{double, value of field ACTENTNOMESS, number of
#'      enterprises for all the activities in France of the given APE code}
#' 	\item{EMPSALNOMESS}{double, value of field EMPSALNOMESS, number of
#'      employees for all the activities in France of the given APE code}
#' 	\item{BAC123VALESE}{double, value of field BAC123VALESE, value of specific
#'      equipment for all the activities in France of the given APE code}
#' 	\item{BAC124VALESE}{double, value of field BAC124VALESE, value of non
#'      specific equipment  for all the activities in France of the given
#'      APE code}
#' 	\item{BAC152VALESE}{double, value of field BAC152VALESE, value of stock
#'      (input) for all the activities in France of the given APE code}
#' 	\item{BAC155VALESE}{double, value of field BAC155VALESE, value of stock
#'      (intermediate) for all the activities in France of the given APE code}
#' 	\item{BAC156VALESE}{double, value of field BAC156VALESE, value of stock
#'      (output) for all the activities in France of the given APE code}
#' }
"ACTIVITY"

#' Expected structure of building files
#' 
#' Expected elements of building files (building.xml or building.yaml).
#'
#' @format A list of element with some useful information on their status:
#' \describe{
#'	\item{STATUS}{character of length 1 with value MANDATORY or OPTIONAL}
#'	\item{VALUE}{character of length 1 with value giving the types of value}
#'	\item{SEVERAL}{optional, boolean of length 1. If true the items may be 
#'      encountered several times}
#'	\item{subitems}{optional, some subitems, which are lists with the same
#'      expected items}
#' }
"BUILDING"

#' Elementary component
#'
#' All available elementary components.
#'
#' @format A data.frame:
#' \describe{
#'  \item{row_name}{name of the elementary component}
#'  \item{category_vulnerability}{factor giving the category of vulnerability}
#'  \item{v_min}{integer, minimum value}
#'  \item{v_max}{integer, maximum value}
#'  \item{v_unit}{factor, unit for v_min and v_max}
#'  \item{v_support}{factor, how should be calculated value}
#'  \item{component_elementary_label_fr}{label in French}
#'  \item{category_activity_01}{factor, categorisation for activity at level 1}
#'  \item{category_activity_02}{factor, categorisation for activity at level 2}
#'  \item{category_dwelling_01}{factor, categorisation for dwelling at level 1}
#' }
"COMPONENT_ELEMENTARY"

#' Elementary damage functions.
#'
#' Elementary damage functions of all available elementary components.
#'
#' @format A list of element of class elementary_damaging:
#' \describe{
#'	\item{value}{array of damage with 3 dimensions: h (height), d (duration),
#' and action}
#'	\item{h_action}{attribute, character of same length as action, giving the
#'      height that shall be used for each action}
#'	\item{dilapidation}{attribute, numeric of same length as action, giving the
#'      dilapidation to be used for each action}
#'	\item{support}{attribute, character of same length as action, giving the
#'      support to be used for each action}
#'	\item{component}{attribute, character of length 1 giving the classification
#'      of the elementary component}
#' }
"DAM"

#' Default value for plotting
#'
#' Default value for plotting
#'
#' @format A data.frame:
#' \describe{
#'  \item{row_name}{name of the elementary component}
#'  \item{col}{color to be used}
#'  \item{lwd}{line width to be used}
#'  \item{density}{density to be used}
#' }
"LEGEND"