#' group elementary damages by room.
#' 
#' @param x, a list
#' @param rooms character vector with the rooms in the dwelling
#' @return a list
#' @examples
#' \dontrun{
#' x <- result[["detail"]]
#' rooms <- levels(data_table[["room"]][["room"]])
#' test <- distrib_by_room(x, rooms) 
#' }
#' 
#' @export

distrib_by_room = function(x, rooms){
    
    # user-defined function by_room
    by_room = function(what, x, room){
      keep = list()
      selection = seq_len(length(names(x[[what]])))
      
      if (what == "furniture"){
        keep = x[[what]][unlist(lapply(selection, function(selection){attr(x[[what]][[selection]], "detail")[["room_name"]]==room}))]
      } else {
        keep = x[[what]][unlist(lapply(selection, function(selection){attr(x[[what]][[selection]], "detail")[["room"]]==room}))]
      }
      
      if (!length(keep)) {
        return(NULL)
      } else {
        return(keep)
      }
    }
  
  # user-defined function distrib_by_room. It calls function by_room
  output = list()
  for(room in rooms){
    output[[room]] = sapply(
      names(x[!sapply(x, is.null)]), 
      FUN = by_room, 
      x = x, 
      room = room, 
      simplify = FALSE, 
      USE.NAMES = TRUE
    )
  }
  return(output)
}
