#' Summarize detailed list of elementary damaging functions.
#' 
#' @param x, object of class elementary_damaging or a list
#' @param who, NULL or character to trace the name of the calling function if an error occurs
#' @return an object of class "damaging"
#' @examples
#' \dontrun{
#' model = analyse_model("test-1", "test", display = TRUE)
#' damage = sumup_damaging(model[["damaging"]][["detail"]])
#' }
#' 
#' @export

sumup_damaging = function(x, who = NULL) {
	if (is.null(who)) who = deparse(sys.call())
	if (methods::is(x, "elementary_damaging")) {
        return(apply(x, 1:2, sum, na.rm = TRUE))
    }
	if (is.list(x)) {
		result = Reduce("+", lapply(x[!sapply(x, is.null)], sumup_damaging, who = who))
		class(result) = "damaging"
		return(invisible(result))
	}
	stop(sprintf("In %s, something inside is not an elementary_damaging found (%s). Please check.", who, class(x)), call. = FALSE)
}

