import numpy as np

class building():
    def __init__(self, nom, S, z0, h):
        self.name = nom
        self.surf = S
        self.z0 = z0
        self.z = []
        self.listIn = []
        self.listOut = []
        
        if (h >= 0):
            self.z.append(z0 + h)
        else:
            print('h cannot be negative: ' + str(h))
            exit()
            
    def updateList(self, exchanges):
        for i, exchange in enumerate(exchanges):
            temp = exchange.nom()
            temp = temp.split("|")
            if (temp[0] == self.name):
                self.listOut.append(i)
            if (temp[1] == self.name):
                self.listIn.append(i)
        
    def nom(self):
        return self.name
    
    def surf(self):
        return self.S
    
    def z0(self):
        return self.z0
    
    def getLevel(self):
        return self.z[len(self.z) - 1]
    
    def compute_dt(self, t, exchanges, dt):
        z = self.z[len(self.z) - 1]
        volume_in = (z - self.z0) * self.surf
        Qtot = 0
        for id in self.listIn:
            Qtot += exchanges[id].Discharge()
        for id in self.listOut:
            Qtot -= exchanges[id].Discharge()
            
        if (Qtot < 0):
            dt = min(dt, volume_in / -Qtot)
        
        return dt
        
    def update(self, exchanges, dt):
        z = self.z[len(self.z) - 1]
        volume_in = z - self.z0
        for id in self.listIn:
            z += exchanges[id].Discharge() * dt / self.surf
        for id in self.listOut:
            z -= exchanges[id].Discharge() * dt / self.surf
            
        self.z.append(z)