# importing libraries
import numpy as np
import pandas as pd

# importing classes
from classes import class_boundary
from classes import class_building
from classes import class_exchange

# defining user-defined functions
def calc_hydrau( dataexch, datarooms, databound, dtmax, t, tmax, ID ):
    boundaries = [] #init empty
    for i in databound.columns[range(1,len(databound.columns))]:
        boundaries.append(class_boundary.boundary(i))

    for i in range(len(databound.index)):
        for j in range(1, len(databound.columns)):
            boundaries[j-1].add(databound.loc[i,"time"], databound.loc[i].iat[j])

    data_buildings = datarooms.to_numpy()
    buildings = [] #init empty
    for data_building in data_buildings:
        buildings.append(class_building.building(data_building[0],
                                                data_building[1],
                                                data_building[2],
                                                data_building[3])) 
    data_exchanges = dataexch.to_numpy()
    exchanges = [] #init empty
    for data_exchange in data_exchanges:
        exchanges.append(class_exchange.exchange(data_exchange[0],
                                                data_exchange[1],
                                                data_exchange[2],
                                                data_exchange[3],
                                                data_exchange[4]))
    ## combining buildings and exchanges
    for building in buildings:
        building.updateList(exchanges)

    # Calculating
    temps = [] #init empty
    temps.append(0)

    stop_prog = False  
    while (t < tmax):
        for exchange in exchanges:
            exchange.getLevel(t, boundaries, buildings)
            exchange.computeDischarge()
            
        for building in buildings:
            dt = dtmax
            dt = building.compute_dt(t, exchanges, dt)
            if (dt < 0):
                print('negative timestep', str(dt))
                stop_prog = True
        
        if (stop_prog == False):
            for building in buildings:
                building.update(exchanges, dt)

            t = t + dt
            temps.append(t)
                
        else:
            break
    # Recovering output from buildings: 
    # building list 
    h = []      # init empty
    eQ = []    # init empty
    eS = []    # init empty
    for i,t in enumerate(temps):
        for building in buildings:
            h.append({
                "time": t,
                building.name: building.z[i]
                })
        for exchange in exchanges:
            eQ.append({
                "time": t,
                exchange.name: exchange.Q[i]
                })
            eS.append({
                "time": t,
                exchange.name: exchange.S[i]
                })    

    # coercing list into DataFrame
    h_df = pd.DataFrame(h)
    eQ_df = pd.DataFrame(eQ)
    eS_df = pd.DataFrame(eS)
    
    # tidying data
    h_df = h_df.groupby(['time']).mean()
    h_df["time"] = h_df.index.values
    h_df["opening_state"] = ID

    eQ_df = eQ_df.groupby(['time']).mean()
    eQ_df["time"] = eQ_df.index.values
    eQ_df["opening_state"] = ID

    eS_df = eS_df.groupby(['time']).mean()
    eS_df["time"] = eS_df.index.values
    eS_df["opening_state"] = ID

    # grouping in list
    depth_exch = [
        h_df,
        eQ_df,
        eS_df
    ]

    # returning list of dataframes    
    return(depth_exch)
